# sartorial
Tailoring custom types to fit Pydantic models, including JSON schema generation and on-the-fly model generation with custom types using JSON Schema's "format" key, allowing lossless serialization/deserialiation of arbitrary models. Contains simple JSON encoding/decoding for most types and the ability to specify them for new types with an interface mixin.
